using System.Collections.Generic;
using Alipay.AopSdk.Core.Response;

namespace Alipay.AopSdk.Core.Request
{
	/// <summary>
	///     AOP API: alipay.pass.tpl.content.add
	/// </summary>
	public class AlipayPassTplContentAddRequest : IAopRequest<AlipayPassTplContentAddResponse>
	{
		/// <summary>
		///     支付宝用户识别信息：  当 recognition_type=1时， recognition_info={“partner_id”:”2088102114633762”,“out_trade_no”:”1234567”}；
		///     当recognition_type=3时，recognition_info={“mobile”:”136XXXXXXXX“}  当recognition_type=4时，
		///     recognition_info={“open_id”:”afbd8d9bb12fc02c5094d8ea89d1fae8“}
		/// </summary>
		public string RecognitionInfo { get; set; }

		/// <summary>
		///     Alipass添加对象识别类型【1--订单信息;3--支付宝用户绑定手机号；4--支付宝OpenId;】
		/// </summary>
		public string RecognitionType { get; set; }

		/// <summary>
		///     支付宝pass模版ID
		/// </summary>
		public string TplId { get; set; }

		/// <summary>
		///     模版动态参数信息【支付宝pass模版参数键值对JSON字符串】
		/// </summary>
		public string TplParams { get; set; }

		#region IAopRequest Members

		private bool needEncrypt;
		private string apiVersion = "1.0";
		private string terminalType;
		private string terminalInfo;
		private string prodCode;
		private string notifyUrl;
		private string returnUrl;
		private AopObject bizModel;

		public void SetNeedEncrypt(bool needEncrypt)
		{
			this.needEncrypt = needEncrypt;
		}

		public bool GetNeedEncrypt()
		{
			return needEncrypt;
		}

		public void SetNotifyUrl(string notifyUrl)
		{
			this.notifyUrl = notifyUrl;
		}

		public string GetNotifyUrl()
		{
			return notifyUrl;
		}

		public void SetReturnUrl(string returnUrl)
		{
			this.returnUrl = returnUrl;
		}

		public string GetReturnUrl()
		{
			return returnUrl;
		}

		public void SetTerminalType(string terminalType)
		{
			this.terminalType = terminalType;
		}

		public string GetTerminalType()
		{
			return terminalType;
		}

		public void SetTerminalInfo(string terminalInfo)
		{
			this.terminalInfo = terminalInfo;
		}

		public string GetTerminalInfo()
		{
			return terminalInfo;
		}

		public void SetProdCode(string prodCode)
		{
			this.prodCode = prodCode;
		}

		public string GetProdCode()
		{
			return prodCode;
		}

		public string GetApiName()
		{
			return "alipay.pass.tpl.content.add";
		}

		public void SetApiVersion(string apiVersion)
		{
			this.apiVersion = apiVersion;
		}

		public string GetApiVersion()
		{
			return apiVersion;
		}

		public IDictionary<string, string> GetParameters()
		{
			var parameters = new AopDictionary();
			parameters.Add("recognition_info", RecognitionInfo);
			parameters.Add("recognition_type", RecognitionType);
			parameters.Add("tpl_id", TplId);
			parameters.Add("tpl_params", TplParams);
			return parameters;
		}

		public AopObject GetBizModel()
		{
			return bizModel;
		}

		public void SetBizModel(AopObject bizModel)
		{
			this.bizModel = bizModel;
		}

		#endregion
	}
}